# load data
moss_spp <- read.csv("species_presence_matrix_ASPA_final.csv", row.names = 1)

## reorder columns - ASPA

numeric_part <- as.numeric(sub("X", "", colnames(moss_spp)))

sorted_indices <- order(numeric_part)

moss_spp <- moss_spp[, c(sorted_indices)]

moss_sp <- t(moss_spp)


###   representation in ASPAS


######   representation in ASPAS   ######


# Sum the rows to get the count of species in each ASPA
species_count_per_aspa <- colSums(moss_sp)

species_count_frequency <- table(species_count_per_aspa)

species_count_df <- as.data.frame(species_count_frequency)

# data frame for plotting
plot_data <- data.frame(ASPAs = species_count_df$species_count_per_aspa,
                        Species = species_count_df$Freq)

ggplot(plot_data, aes(x = ASPAs, y = Species)) +
    geom_bar(stat = "identity", 
             fill = "forestgreen", 
             color = "black",
             alpha = 0.5,
             size = 0.25) +
    theme_classic() +
    ylim(0, 40) +
    labs(x = "Number of ASPAs",
         y = "Number of Species") +
    theme(axis.line = element_line(color = "black"),
          axis.text = element_text(color = "black", size = 11))+
    annotate("text", x = -Inf, y = Inf, label = "B", 
             vjust = 1, hjust = -0.5, size = 4, color = "black", parse = TRUE)


#### redudancy 


#load data
moss_spp <- read.csv("species_presence_matrix_ASPA_final.csv", row.names = 1)

#reorder columns - ASPA

# Extract numeric part of column names
numeric_part <- as.numeric(sub("X", "", colnames(moss_spp)))

# Get sorted indices
sorted_indices <- order(numeric_part)

# Reorder columns
moss_spp <- moss_spp[, c(sorted_indices)]

# Select species with more than 5 records from dataframe
# counting the number of grid cells per species

selected_species <- result_df$Species[result_df$n_records >= 5]


# Create a matrix to store presence/absence information for selected species
selected_matrix <- moss_spp[selected_species, ]

selected_matrix <- na.omit(selected_matrix)

# Count the number of ASPAs where each selected species is present
aspas_counts <- rowSums(selected_matrix)

# Count the frequency of the number of ASPAs with > 5 species
frequency_table <- table(aspas_counts)

# Convert the frequency table to a data frame for ggplot
frequency_df <- as.data.frame(frequency_table)
names(frequency_df) <- c("Num_ASPAs", "Frequency")


# Num_ASPAs values to be added with Frequency 0
values_to_add <- c(11, 13, 15)

# Convert Num_ASPAs to numeric in the existing data frame
frequency_df$Num_ASPAs <- as.numeric(as.character(frequency_df$Num_ASPAs))

# Creating a data frame for new rows
new_rows <- data.frame(Num_ASPAs = values_to_add, Frequency = 0)

# Convert Num_ASPAs to numeric in the new rows
new_rows$Num_ASPAs <- as.numeric(as.character(new_rows$Num_ASPAs))

# Combine existing data frame with new rows and arrange in ascending order
frequency_df <- bind_rows(frequency_df, new_rows) %>%
  arrange(Num_ASPAs)

frequency_df$Num_ASPAs <- as.factor(frequency_df$Num_ASPAs)

# Create a bar plot with ggplot2
(red <- ggplot(frequency_df, aes(x = Num_ASPAs, y = Frequency)) +
  geom_bar(stat = "identity", 
           fill = "forestgreen", 
           color = "black",
           alpha = 0.5,
           size = 0.25)  +
  theme_classic() +
  scale_x_discrete(expand = c(0.05, 0)) +
  scale_y_continuous(breaks = c(0, 5, 10, 15, 20, 25)) + 
  ylim(0, 25) +
    labs(x = "Number of ASPAs",
       y = "Number of Species") +
  theme(axis.line = element_line(color = "black"),
        axis.text = element_text(color = "black", size = 10)))

ggsave("redundancy.png", plot = red, 
       width = 8, height = 6, units = "in", dpi = 600)  
